class LearningObjectBuilder
  extend RepositoriesProxy

  ##
  # receive a list of ids and return a list of learning objects
  # useful for search pagination
  #
  def self.build(objects = [])
    lo = []
    objects.each do |object|
      o = Rails.cache.fetch(cache_key(object[:@rid], object[:last_modified]))

      # TODO: fix learning_object_repository call
      o = learning_object_repository.find object[:@rid] if o.nil?

      lo << o
    end
    lo
  end

  def self.build_from_orientdb(args = {})
    lo = nil
    unless args.nil?
      # cache object when build
      lo = Rails.cache.fetch(cache_key(args['@rid'], args['last_modified']), expires_in: 12.hours) do
        obj = LearningObject.new(
          id: args['@rid'],
          name: args['name'],
          description: args['description'],
          thumbnail: (args['thumbnail'] or ''),
          id_dspace: args['id_dspace'],
          type: args['type'],
          bitstreams: args['bitstreams'],
          last_modified: args['last_modified'],
          metadata: JSON.parse(args['metadata'])
        )
        obj.created_at = DateTime.strptime(args['created_at'], "%Y-%m-%d %H:%M:%S") unless args['created_at'].nil?
        obj.last_modified = DateTime.strptime(args['last_modified'], "%Y-%m-%d %H:%M:%S") unless args['last_modified'].nil?
        obj.published_at = DateTime.strptime(args['published_at'], "%Y-%m-%d %H:%M:%S") unless args['published_at'].nil?
        obj.likes = args.key?('in_Likes') ? args['in_Likes'].size : 0
        obj.views = args.key?('in_Views') ? args['in_Views'].size : 0
        obj
      end
    end
    lo
  end

  def self.cache_key(rid, last_modified)
    rid + '/' + last_modified
  end
end
