class CollectionsController < ApplicationController
  before_action :set_collection, only: [:show, :update, :destroy, :like, :add_learning_object]
  before_action :authenticate_user!, except: [:index, :show]

  # GET /collections
  # GET /collections.json
  def index
    @collections = collection_repository.all current_user
  end

  # GET /collections/1
  # GET /collections/1.json
  def show
    @user = @collection.owner
  end

  # POST /collections/1/like
  def like
    collection_repository.like @collection
  end

  # POST /collections
  # POST /collections.json
  def create
    @collection = Collection.new(collection_params)
    @collection.owner = current_user

    respond_to do |format|
      if collection_repository.create @collection
        format.html { redirect_to @collection, notice: 'Collection was successfully created.' }
      else
        format.html { render :new }
      end
    end
  end

  # PATCH/PUT /collections/1
  # PATCH/PUT /collections/1.json
  def update
    respond_to do |format|
      if collection_repository.update(collection_params)
        format.html { redirect_to @collection, notice: 'Collection was successfully updated.' }
      else
        format.html { render :edit }
      end
    end
  end

  # DELETE /collections/1
  # DELETE /collections/1.json
  def destroy
    collection_repository.destroy @collection

    respond_to do |format|
      format.html { redirect_to collections_url, notice: 'Learning object was successfully destroyed.' }
    end
  end

  # POST /collections/1/learning_object/43
  def add_learning_object
    learning_object = learning_object_repository.find params[:learning_object_id]
    @collection.add learning_object
    collection_repository.save @collection

    if request.xhr?
      render json: {collections: @collection.learning_objects.as_json}
    end
  end

  private

  def set_collection
    @collection = collection_repository.find params[:id]
  end

  # Never trust parameters from the scary internet, only allow the white list through.
  def collection_params
    params.require(:collection).permit(:name, :description, learning_objects: [])
  end

end
