class SearchController < ApplicationController
  include SearchEngine::OrientdbLucene

  def index
    @types = learning_object_repository.types

    @subjects = ['Arte', 'Biologia', 'Ciências', 'Educação Física', 'Filosofia', 'Física', 'Geografia', 'História', 'Matemática', 'Português', 'Química', 'Sociologia']

    # 'Ensino Infantil' and 'Ensino Superior' will only exist after creation of new learning objects or update of the old ones
    @school_levels = ['Ensino Infantil', 'Ensino Fundamental Inicial', 'Ensino Fundamental', 'Ensino Fundamental Final', 'Ensino Médio', 'Ensino Superior', 'Ensino Profissionalizante']
  end

  def fetch
    objectsFound = []

    params[:subject]= params[:subject].split(', ')
    params[:type] = params[:type].split(', ')
    params[:school_level] = params[:school_level].split(', ')
    params[:year] = params[:year].split('-').take(2)
    page=1
    if (params[:page])
      page = params[:page].to_i
    end

    @pagination_limit=10

    unless params[:query].blank?
      objectsFound = search params
      @numFound = objectsFound.length
    end

    @result = Kaminari.paginate_array(objectsFound).page(page).per(@pagination_limit)
    @last_page = (@result.num_pages <= page) ? true : false;

    # build objects from one page only
    @objects = LearningObjectBuilder.build(@result)

    render partial: 'search/fetch'
  end

  def autocomplete
    begin
      auto = AutocompleteService.new
      query = params['q'] || ''
      json_data = auto.query(query)
      render text: json_data
    rescue
      render text: '[]'
    end
  end

end
