class Collection
  include ActiveModel::Model
  attr_accessor :id, :created_at, :last_modified, :name, :description, :privacy,
                :owner, :learning_objects
  validates_presence_of :name, :created_at, :owner, :learning_objects

  def initialize(params = {})
    super(defaults.merge(params))
  end

  ##
  # Add +learning_object+ to collection
  #
  # After adding some learning object to collection, you must use CollectionRepository to persist
  # the changes.
  #
  # Example:
  #   @test_collection = Collection.new(name: 'test', description: 'test', owner: current_user)
  #   @test_collection.add @learning_object
  #
  #   @test_collection.learning_objects # [@learning_object]
  #   collection_repository.save @test_collection
  def add(learning_object)
    learning_objects.append learning_object
  end

  ##
  # Remove +learning_object+ from collection
  #
  # After remove some learning object to collection, you must use CollectionRepository to persist
  # the changes.
  def remove(learning_object)
    learning_objects.delete learning_object
  end

  def valid?
    !@name.blank?
  end

  private

  def defaults
    {
        created_at: DateTime.now.strftime("%Y-%m-%d %H:%M:%S"),
        last_modified: DateTime.now.strftime("%Y-%m-%d %H:%M:%S"),
        owner: User.new,
        learning_objects: [],
        privacy: 'private'
    }
  end

end
