module OrientDb
  class CollectionRepository < Base
    include OrientDb::Methods::EdgeMethods
    include OrientDb::Methods::FinderMethods

    def build_object(args={})
      Collection.new(map_object_hash(args))
    end

    def save(collection = Collection.new)
      collection.learning_objects.each do |learning_object|
        query = sprintf("update %s add learning_objects = %s", collection.id, learning_object.id)
        connection.command query
      end
    end

    def get_number_of_collections
      get_number_of odb_class
    end

    def create_bookmarks_collection(user)
      bookmarks = Bookmarks.new(owner: user)
      create bookmarks
    end

    def destroy_bookmarks_collection(user)
      bookmarks = user.bookmarks
      if has_bookmarks? user
        destroy bookmarks
      end
    end

    def create(object)
      super(object)
      create_edge "BelongsTo", object.id, object.owner.rid
      object
    end

    def destroy(object)
      super(object)
      destroy_edge "BelongsTo", object.id, object.owner.rid
    end

    def all(user)
      query = sprintf("select * from (select expand(in('BelongsTo')) from %s) where name<>'Bookmarks'", user.rid)
      build_objects connection.query(query)
    end

    def find_by_learning_object(learning_object)
      if learning_object.id.to_s.empty?
        return []
      end

      query = sprintf("select * from %s where learning_objects contains %s", odb_class, learning_object.id)
      build_objects connection.query(query)
    end

    def bookmarks(user)
      query = sprintf("select * from (select expand(in('BelongsTo')) from %s) where name='Bookmarks'", user.rid)
      result = build_objects(connection.query(query))
      if !result.empty?
        return result.first
      end
      create_bookmarks_collection(user)
    end

    def has_bookmarks?(user)
      if !user.bookmarks.id.nil? && !user.rid.nil?
        edge_exists? 'BelongsTo', user.bookmarks.id, user.rid
      end
    end

    def build_hash(object)
      hash = super(object)
      hash.delete("owner") # delete owner, because it represents an edge in schema
      hash.merge('name' => object.name) # forces name property for bookmarks
    end

    private

    def map_object_hash(hash={})
      {
          created_at: hash['created_at'],
          last_modified: hash['last_modified'],
          learning_objects: hash['created_at'],
          privacy: hash['privacy'],
          name: hash['name'],
          id: hash['@rid']
      }
    end

    def odb_class
      'Collection'
    end

  end
end
