class ScoreCalculatorWorker
  include Sidekiq::Worker
  sidekiq_options queue: :score
  include RepositoriesProxy

  def perform(rid)
    object = learning_object_repository.find(rid)

    unless object.blank?
        # Weights to score. Sum must be 1000
        weights = {
            "thumbnail": 250,
            "description": 150,
            "likes": 250,
            "views": 150,
            "downloads":200
          }

    score = 0

    # 250 points if it has thumbnail
    score += weights[:thumbnail] unless object.thumbnail.empty?

    # 150 points if it has description
    score += weights[:description] unless object.description.empty?

    # range to 250 points, for normalized likes ( maxLikes/actualLike => [0..1] )
    likes = learning_object_repository.count_likes(object)
    score += (likes / learning_object_repository.max_likes)*weights[:likes]  unless likes < 1

    # range to 200 points, for normalized views ( maxLikes/actualLike => [0..1] )
    views = learning_object_repository.count_views(object)
    score += (views / learning_object_repository.max_views)*weights[:views] unless views < 1

    downloads = learning_object_repository.count_downloads(object)
    score += (downloads / learning_object_repository.max_downloads)*weights[:downloads] unless views < 1

    learning_object_repository.update_property(object, 'score', score)
    
    end
  end
end
